/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
 *
 * Licensed under the Academic Free License version 2.1
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef FILE_MONITOR_H
#define FILE_MONITOR_H

#include <glib-object.h>

G_BEGIN_DECLS

#define TYPE_FILE_MONITOR         (file_monitor_get_type ())
#define FILE_MONITOR(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_FILE_MONITOR, FileMonitor))
#define FILE_MONITOR_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), TYPE_FILE_MONITOR, FileMonitorClass))
#define IS_FILE_MONITOR(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_FILE_MONITOR))
#define IS_FILE_MONITOR_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_FILE_MONITOR))
#define FILE_MONITOR_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_FILE_MONITOR, FileMonitorClass))

typedef struct FileMonitorPrivate FileMonitorPrivate;

typedef struct
{
        GObject               parent;
        FileMonitorPrivate *priv;
} FileMonitor;

typedef struct
{
        GObjectClass parent_class;
} FileMonitorClass;

typedef enum
{
        FILE_MONITOR_EVENT_NONE    = 1 << 0,
        FILE_MONITOR_EVENT_ACCESS  = 1 << 1,
        FILE_MONITOR_EVENT_CREATE  = 1 << 2,
        FILE_MONITOR_EVENT_DELETE  = 1 << 3,
        FILE_MONITOR_EVENT_CHANGE  = 1 << 4,
} FileMonitorEvent;

typedef enum
{
        FILE_MONITOR_ERROR_GENERAL
} FileMonitorError;

#define FILE_MONITOR_ERROR file_monitor_error_quark ()

typedef void (*FileMonitorNotifyFunc) (FileMonitor      *monitor,
                                          FileMonitorEvent  event,
                                          const char         *path,
                                          gpointer            user_data);

GQuark           file_monitor_error_quark           (void);
GType            file_monitor_get_type              (void);

FileMonitor     *file_monitor_new                   (void);

guint            file_monitor_add_notify            (FileMonitor          *monitor,
                                                     const char             *path,
                                                     int                     mask,
                                                     FileMonitorNotifyFunc notify_func,
                                                     gpointer                data);
void             file_monitor_remove_notify         (FileMonitor          *monitor,
                                                     guint                   id);

G_END_DECLS

#endif /* FILE_MONITOR_H */
